#http://cms-bucket.nosdn.127.net/30b3a22ed1ae458d96de6ccdddec7cd020170330025319.png
#这样的地址就没有content-length
{
    'Last-Modified': 'Fri, 05 Jun 2015 08:57:04 GMT', 
    'Access-Control-Allow-Origin': '*', 
    'Connection': 'keep-alive', 
    'Expires': 'Mon, 05 Mar 2018 15:42:08 GMT', 
    'X-Via': '1.1 xxz162:0 (Cdn Cache Server V2.0), 1.1 jw140:6 (Cdn Cache Server V2.0)', 
    'cdn-ip': '159.226.225.140', 
    'X_cache': 'MISS from bjzw-img-proxy2', 
    'Age': '1', 
    'Date': 'Thu, 04 Jan 2018 15:42:08 GMT', 
    'cdn-source': 'chinanetcenter', 
    'Content-Encoding': 'gzip', 
    'Server': 'nginx', 
    'Content-Type': 'image/jpeg', 
    'Access-Control-Allow-Methods': 'GET', 
    'Transfer-Encoding': 'chunked', 
    'Vary': 'Accept-Encoding', 
    'Accept-Ranges': 'bytes', 
    'Access-Control-Allow-Credentials': 'false', 
    'Cache-Control': 'max-age=5184000', 
    'cdn-user-ip': '159.226.43.35'
}

